==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/GeographicMarkerSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicMapSeriesHost } from "./GeographicMapSeriesHost";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { DataTemplate } from "igniteui-webcomponents-core";
import { Brush } from "igniteui-webcomponents-core";
import { runOn, delegateCombine, typeCast, enumGetBox, markType, markDep } from "igniteui-webcomponents-core";
import { MarkerSeries } from "igniteui-webcomponents-charts";
import { Defaults } from "igniteui-webcomponents-charts";
import { PropertyMetadata } from "igniteui-webcomponents-core";
import { DeviceUtils } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var GeographicMarkerSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMarkerSeries, _super);
    function GeographicMarkerSeries() {
        var _this = _super.call(this) || this;
        var a = _this.t5;
        a.propertyUpdated = delegateCombine(a.propertyUpdated, runOn(_this, _this.ut));
        return _this;
    }
    GeographicMarkerSeries.prototype.qx = function () {
        return this.uu;
    };
    GeographicMarkerSeries.prototype.s1 = function () {
        return this.u7;
    };
    GeographicMarkerSeries.prototype.s2 = function () {
        return this.u8;
    };
    GeographicMarkerSeries.prototype.ht = function () {
        return this.ug;
    };
    GeographicMarkerSeries.prototype.ky = function () {
        var a = typeCast(MarkerSeries.$, this.t5);
        if (a == null) {
            return "Unknown";
        }
        return a.ky();
    };
    GeographicMarkerSeries.prototype.ut = function (a, b) {
        var c = typeCast(MarkerSeries.$, this.t5);
        if (c == null) {
            return;
        }
        if (b.propertyName == "ActualMarkerTemplate") {
            this.uu = c.uw;
        }
        else if (b.propertyName == "ActualMarkerOutline") {
            this.u8 = c.vd;
        }
        else if (b.propertyName == "ActualMarkerBrush") {
            this.u7 = c.vc;
        }
    };
    GeographicMarkerSeries.prototype.pa = function (a, b, c, d) {
        _super.prototype.pa.call(this, a, b, c, d);
        switch (b) {
            case GeographicMarkerSeries.$$p[3]:
                this.t5.ve = this.u9;
                break;
            case GeographicMarkerSeries.$$p[6]:
                this.t5.vf = this.va;
                break;
            case GeographicMarkerSeries.$$p[5]:
                this.t5.t9 = this.ue;
                break;
            case GeographicMarkerSeries.$$p[4]:
                this.t5.t5 = this.ud;
                break;
            case GeographicMarkerSeries.$$p[9]:
                this.t5.uc = this.uf;
                break;
            case GeographicMarkerSeries.$$p[7]:
                this.t5.uy = this.uv;
                break;
            case GeographicMarkerSeries.$$p[8]:
                this.t5.uh = this.ug;
                break;
            case GeographicMarkerSeries.$$p[10]:
                this.t5.w3 = this.uh;
                break;
        }
    };
    GeographicMarkerSeries.$t = markType(GeographicMarkerSeries, 'GeographicMarkerSeries', GeographicMapSeriesHost.$);
    GeographicMarkerSeries.$$p = markDep(DependencyProperty, PropertyMetadata, GeographicMarkerSeries, 'raisePropertyChanged', ['ActualMarkerBrush:u7:uw', [Brush.$], 'ActualMarkerOutline:u8:ux', [Brush.$], 'ActualMarkerTemplate:uu:uy', [DataTemplate.$, null], 'MarkerBrush:u9:uz', [Brush.$], 'MarkerFillMode:ud:u0', [MarkerFillMode_$type, enumGetBox(MarkerFillMode_$type, 0)], 'MarkerOutlineMode:ue:u1', [MarkerOutlineMode_$type, enumGetBox(MarkerOutlineMode_$type, 0)], 'MarkerOutline:va:u2', [Brush.$], 'MarkerTemplate:uv:u3', [DataTemplate.$, null], 'MarkerThickness:ug:u4', [1, DeviceUtils.g(2)], 'MarkerType:uf:u5', [MarkerType_$type, enumGetBox(MarkerType_$type, Defaults.e)], 'MaximumMarkers:uh:u6', [1, 400]]);
    return GeographicMarkerSeries;
}(GeographicMapSeriesHost));
export { GeographicMarkerSeries };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/GeographicMarkerSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicMapSeriesHost } from "./GeographicMapSeriesHost";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { DataTemplate } from "igniteui-webcomponents-core";
import { Brush } from "igniteui-webcomponents-core";
import { runOn, delegateCombine, typeCast, enumGetBox, markType, markDep } from "igniteui-webcomponents-core";
import { MarkerSeries } from "igniteui-webcomponents-charts";
import { Defaults } from "igniteui-webcomponents-charts";
import { PropertyMetadata } from "igniteui-webcomponents-core";
import { DeviceUtils } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var GeographicMarkerSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMarkerSeries, _super);
    function GeographicMarkerSeries() {
        var _this = _super.call(this) || this;
        var a = _this.w2;
        a.propertyUpdated = delegateCombine(a.propertyUpdated, runOn(_this, _this.xq));
        return _this;
    }
    GeographicMarkerSeries.prototype.s1 = function () {
        return this.xr;
    };
    GeographicMarkerSeries.prototype.vn = function () {
        return this.x4;
    };
    GeographicMarkerSeries.prototype.vo = function () {
        return this.x5;
    };
    GeographicMarkerSeries.prototype.io = function () {
        return this.xd;
    };
    GeographicMarkerSeries.prototype.ma = function () {
        var a = typeCast(MarkerSeries.$, this.w2);
        if (a == null) {
            return "Unknown";
        }
        return a.ma();
    };
    GeographicMarkerSeries.prototype.xq = function (a, b) {
        var c = typeCast(MarkerSeries.$, this.w2);
        if (c == null) {
            return;
        }
        if (b.propertyName == "ActualMarkerTemplate") {
            this.xr = c.x2;
        }
        else if (b.propertyName == "ActualMarkerOutline") {
            this.x5 = c.yk;
        }
        else if (b.propertyName == "ActualMarkerBrush") {
            this.x4 = c.yj;
        }
    };
    GeographicMarkerSeries.prototype.ra = function (a, b, c, d) {
        _super.prototype.ra.call(this, a, b, c, d);
        switch (b) {
            case GeographicMarkerSeries.$$p[3]:
                this.w2.yl = this.x6;
                break;
            case GeographicMarkerSeries.$$p[6]:
                this.w2.ym = this.x7;
                break;
            case GeographicMarkerSeries.$$p[5]:
                this.w2.w6 = this.xb;
                break;
            case GeographicMarkerSeries.$$p[4]:
                this.w2.w2 = this.xa;
                break;
            case GeographicMarkerSeries.$$p[9]:
                this.w2.xc = this.xc;
                break;
            case GeographicMarkerSeries.$$p[7]:
                this.w2.x4 = this.xs;
                break;
            case GeographicMarkerSeries.$$p[8]:
                this.w2.xl = this.xd;
                break;
            case GeographicMarkerSeries.$$p[10]:
                this.w2.aab = this.xe;
                break;
        }
    };
    GeographicMarkerSeries.$t = markType(GeographicMarkerSeries, 'GeographicMarkerSeries', GeographicMapSeriesHost.$);
    GeographicMarkerSeries.$$p = markDep(DependencyProperty, PropertyMetadata, GeographicMarkerSeries, 'raisePropertyChanged', ['ActualMarkerBrush:x4:xt', [Brush.$], 'ActualMarkerOutline:x5:xu', [Brush.$], 'ActualMarkerTemplate:xr:xv', [DataTemplate.$, null], 'MarkerBrush:x6:xw', [Brush.$], 'MarkerFillMode:xa:xx', [MarkerFillMode_$type, enumGetBox(MarkerFillMode_$type, 0)], 'MarkerOutlineMode:xb:xy', [MarkerOutlineMode_$type, enumGetBox(MarkerOutlineMode_$type, 0)], 'MarkerOutline:x7:xz', [Brush.$], 'MarkerTemplate:xs:x0', [DataTemplate.$, null], 'MarkerThickness:xd:x1', [1, DeviceUtils.g(2)], 'MarkerType:xc:x2', [MarkerType_$type, enumGetBox(MarkerType_$type, Defaults.e)], 'MaximumMarkers:xe:x3', [1, 400]]);
    return GeographicMarkerSeries;
}(GeographicMapSeriesHost));
export { GeographicMarkerSeries };
